==> libreoffice-extensions-3.3.1.2.tar.bz2: libreoffice-extensions-3.3.1.2/sdext/source/pdfimport/tree/treevisitorfactory.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sdext.hxx"

#include "treevisitorfactory.hxx"
#include "writertreevisiting.hxx"
#include "drawtreevisiting.hxx"

namespace pdfi
{
    struct WriterTreeVisitorFactory : public TreeVisitorFactory
    {
        WriterTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlEmitter(rEmitContext));
        }
    };

    struct ImpressTreeVisitorFactory : public TreeVisitorFactory
    {
        ImpressTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
                                                                            DrawXmlEmitter::IMPRESS_DOC));
        }
    };

    struct DrawTreeVisitorFactory : public TreeVisitorFactory
    {
        DrawTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
                                                                            DrawXmlEmitter::DRAW_DOC));
        }
    };

    TreeVisitorFactorySharedPtr createWriterTreeVisitorFactory() 
    { 
        return TreeVisitorFactorySharedPtr(new WriterTreeVisitorFactory());
    }
    TreeVisitorFactorySharedPtr createImpressTreeVisitorFactory()
    { 
        return TreeVisitorFactorySharedPtr(new ImpressTreeVisitorFactory());
    }
    TreeVisitorFactorySharedPtr createDrawTreeVisitorFactory()
    { 
        return TreeVisitorFactorySharedPtr(new DrawTreeVisitorFactory());
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-extensions-3.4.4.2.tar.bz2: libreoffice-extensions-3.4.4.2/sdext/source/pdfimport/tree/treevisitorfactory.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_sdext.hxx"

#include "treevisitorfactory.hxx"
#include "writertreevisiting.hxx"
#include "drawtreevisiting.hxx"

namespace pdfi
{
    struct WriterTreeVisitorFactory : public TreeVisitorFactory
    {
        WriterTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor&) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlEmitter(rEmitContext));
        }
    };

    struct ImpressTreeVisitorFactory : public TreeVisitorFactory
    {
        ImpressTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
                                                                            DrawXmlEmitter::IMPRESS_DOC,
                                                                            rProc
                                                                            ));
        }
    };

    struct DrawTreeVisitorFactory : public TreeVisitorFactory
    {
        DrawTreeVisitorFactory() {}

        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
            StyleContainer& rStyles, 
            PDFIProcessor&  rProc ) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
        }

        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor& rProc) const
        {
            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
                                                                            DrawXmlEmitter::DRAW_DOC,
                                                                            rProc
                                                                            ));
        }
    };

    TreeVisitorFactorySharedPtr createWriterTreeVisitorFactory() 
    { 
        return TreeVisitorFactorySharedPtr(new WriterTreeVisitorFactory());
    }
    TreeVisitorFactorySharedPtr createImpressTreeVisitorFactory()
    { 
        return TreeVisitorFactorySharedPtr(new ImpressTreeVisitorFactory());
    }
    TreeVisitorFactorySharedPtr createDrawTreeVisitorFactory()
    { 
        return TreeVisitorFactorySharedPtr(new DrawTreeVisitorFactory());
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
